# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v0/sequencing.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v0/sequencing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from ...v0 import trace_context_pb2 as com_dot_digitalasset_dot_canton_dot_v0_dot_trace__context__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4com/digitalasset/canton/protocol/v0/sequencing.proto\x12#com.digitalasset.canton.protocol.v0\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a.com/digitalasset/canton/v0/trace_context.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xf5\x02\n\x0eSequencedEvent\x12\x18\n\x07\x63ounter\x18\x01 \x01(\x03R\x07\x63ounter\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x12;\n\nmessage_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tmessageId\x12J\n\x05\x62\x61tch\x18\x05 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v0.CompressedBatchR\x05\x62\x61tch\x12i\n\x14\x64\x65liver_error_reason\x18\x06 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v0.DeliverErrorReasonR\x12\x64\x65liverErrorReason\"\xb5\x02\n\x1dPossiblyIgnoredSequencedEvent\x12\x18\n\x07\x63ounter\x18\x01 \x01(\x03R\x07\x63ounter\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12M\n\rtrace_context\x18\x03 \x01(\x0b\x32(.com.digitalasset.canton.v0.TraceContextR\x0ctraceContext\x12\x1d\n\nis_ignored\x18\x04 \x01(\x08R\tisIgnored\x12R\n\nunderlying\x18\x05 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.SignedContentR\nunderlying\"\x81\x01\n\x0eRecipientsTree\x12\x1e\n\nrecipients\x18\x01 \x03(\tR\nrecipients\x12O\n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x33.com.digitalasset.canton.protocol.v0.RecipientsTreeR\x08\x63hildren\"j\n\nRecipients\x12\\\n\x0frecipients_tree\x18\x01 \x03(\x0b\x32\x33.com.digitalasset.canton.protocol.v0.RecipientsTreeR\x0erecipientsTree\"u\n\x08\x45nvelope\x12\x18\n\x07\x63ontent\x18\x01 \x01(\x0cR\x07\x63ontent\x12O\n\nrecipients\x18\x02 \x01(\x0b\x32/.com.digitalasset.canton.protocol.v0.RecipientsR\nrecipients\"\xd2\x01\n\x0f\x43ompressedBatch\x12g\n\talgorithm\x18\x01 \x01(\x0e\x32I.com.digitalasset.canton.protocol.v0.CompressedBatch.CompressionAlgorithmR\talgorithm\x12)\n\x10\x63ompressed_batch\x18\x02 \x01(\x0cR\x0f\x63ompressedBatch\"+\n\x14\x43ompressionAlgorithm\x12\t\n\x05None_\x10\x00\x12\x08\n\x04Gzip\x10\x01\"T\n\x05\x42\x61tch\x12K\n\tenvelopes\x18\x01 \x03(\x0b\x32-.com.digitalasset.canton.protocol.v0.EnvelopeR\tenvelopes\"\xe9\x01\n\rSignedContent\x12\x35\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.BytesValueR\x07\x63ontent\x12L\n\nsignatures\x18\x02 \x01(\x0b\x32,.com.digitalasset.canton.crypto.v0.SignatureR\nsignatures\x12S\n\x18timestamp_of_signing_key\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x15timestampOfSigningKey\"l\n\x12\x44\x65liverErrorReason\x12%\n\rbatch_invalid\x18\x01 \x01(\tH\x00R\x0c\x62\x61tchInvalid\x12%\n\rbatch_refused\x18\x02 \x01(\tH\x00R\x0c\x62\x61tchRefusedB\x08\n\x06reason\"A\n\x10ServiceAgreement\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nlegal_text\x18\x02 \x01(\tR\tlegalText\"\x8b\x07\n\x16StaticDomainParameters\x12R\n\x17reconciliation_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x16reconciliationInterval\x12\x37\n\x18max_rate_per_participant\x18\x02 \x01(\rR\x15maxRatePerParticipant\x12\x37\n\x18max_inbound_message_size\x18\x03 \x01(\rR\x15maxInboundMessageSize\x12\x30\n\x14unique_contract_keys\x18\x04 \x01(\x08R\x12uniqueContractKeys\x12t\n\x1crequired_signing_key_schemes\x18\x05 \x03(\x0e\x32\x33.com.digitalasset.canton.crypto.v0.SigningKeySchemeR\x19requiredSigningKeySchemes\x12}\n\x1frequired_encryption_key_schemes\x18\x06 \x03(\x0e\x32\x36.com.digitalasset.canton.crypto.v0.EncryptionKeySchemeR\x1crequiredEncryptionKeySchemes\x12z\n\x1erequired_symmetric_key_schemes\x18\x07 \x03(\x0e\x32\x35.com.digitalasset.canton.crypto.v0.SymmetricKeySchemeR\x1brequiredSymmetricKeySchemes\x12j\n\x18required_hash_algorithms\x18\x08 \x03(\x0e\x32\x30.com.digitalasset.canton.crypto.v0.HashAlgorithmR\x16requiredHashAlgorithms\x12q\n\x1brequired_crypto_key_formats\x18\t \x03(\x0e\x32\x32.com.digitalasset.canton.crypto.v0.CryptoKeyFormatR\x18requiredCryptoKeyFormats\x12)\n\x10protocol_version\x18\n \x01(\tR\x0fprotocolVersion\"\xde\x03\n\x17\x44ynamicDomainParameters\x12[\n\x1cparticipant_response_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1aparticipantResponseTimeout\x12U\n\x19mediator_reaction_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x17mediatorReactionTimeout\x12[\n\x1ctransfer_exclusivity_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1atransferExclusivityTimeout\x12M\n\x15topology_change_delay\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x13topologyChangeDelay\x12\x63\n!ledger_time_record_time_tolerance\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1dledgerTimeRecordTimeTolerance\"\xcd\x03\n\tHandshake\x1a\x9b\x01\n\x07Request\x12\x38\n\x18\x63lient_protocol_versions\x18\x01 \x03(\tR\x16\x63lientProtocolVersions\x12V\n\x18minimum_protocol_version\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x16minimumProtocolVersion\x1a\xf3\x01\n\x08Response\x12\x36\n\x17server_protocol_version\x18\x01 \x01(\tR\x15serverProtocolVersion\x12R\n\x07success\x18\x02 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v0.Handshake.SuccessH\x00R\x07success\x12R\n\x07\x66\x61ilure\x18\x03 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v0.Handshake.FailureH\x00R\x07\x66\x61ilureB\x07\n\x05value\x1a\t\n\x07Success\x1a!\n\x07\x46\x61ilure\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason\"\xd6\x02\n\x11SubmissionRequest\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1d\n\nmessage_id\x18\x02 \x01(\tR\tmessageId\x12\x1d\n\nis_request\x18\x03 \x01(\x08R\tisRequest\x12J\n\x05\x62\x61tch\x18\x04 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v0.CompressedBatchR\x05\x62\x61tch\x12J\n\x13max_sequencing_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11maxSequencingTime\x12S\n\x18timestamp_of_signing_key\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x15timestampOfSigningKeyBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v0.sequencing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0'
  _globals['_SEQUENCEDEVENT']._serialized_start=287
  _globals['_SEQUENCEDEVENT']._serialized_end=660
  _globals['_POSSIBLYIGNOREDSEQUENCEDEVENT']._serialized_start=663
  _globals['_POSSIBLYIGNOREDSEQUENCEDEVENT']._serialized_end=972
  _globals['_RECIPIENTSTREE']._serialized_start=975
  _globals['_RECIPIENTSTREE']._serialized_end=1104
  _globals['_RECIPIENTS']._serialized_start=1106
  _globals['_RECIPIENTS']._serialized_end=1212
  _globals['_ENVELOPE']._serialized_start=1214
  _globals['_ENVELOPE']._serialized_end=1331
  _globals['_COMPRESSEDBATCH']._serialized_start=1334
  _globals['_COMPRESSEDBATCH']._serialized_end=1544
  _globals['_COMPRESSEDBATCH_COMPRESSIONALGORITHM']._serialized_start=1501
  _globals['_COMPRESSEDBATCH_COMPRESSIONALGORITHM']._serialized_end=1544
  _globals['_BATCH']._serialized_start=1546
  _globals['_BATCH']._serialized_end=1630
  _globals['_SIGNEDCONTENT']._serialized_start=1633
  _globals['_SIGNEDCONTENT']._serialized_end=1866
  _globals['_DELIVERERRORREASON']._serialized_start=1868
  _globals['_DELIVERERRORREASON']._serialized_end=1976
  _globals['_SERVICEAGREEMENT']._serialized_start=1978
  _globals['_SERVICEAGREEMENT']._serialized_end=2043
  _globals['_STATICDOMAINPARAMETERS']._serialized_start=2046
  _globals['_STATICDOMAINPARAMETERS']._serialized_end=2953
  _globals['_DYNAMICDOMAINPARAMETERS']._serialized_start=2956
  _globals['_DYNAMICDOMAINPARAMETERS']._serialized_end=3434
  _globals['_HANDSHAKE']._serialized_start=3437
  _globals['_HANDSHAKE']._serialized_end=3898
  _globals['_HANDSHAKE_REQUEST']._serialized_start=3451
  _globals['_HANDSHAKE_REQUEST']._serialized_end=3606
  _globals['_HANDSHAKE_RESPONSE']._serialized_start=3609
  _globals['_HANDSHAKE_RESPONSE']._serialized_end=3852
  _globals['_HANDSHAKE_SUCCESS']._serialized_start=3854
  _globals['_HANDSHAKE_SUCCESS']._serialized_end=3863
  _globals['_HANDSHAKE_FAILURE']._serialized_start=3865
  _globals['_HANDSHAKE_FAILURE']._serialized_end=3898
  _globals['_SUBMISSIONREQUEST']._serialized_start=3901
  _globals['_SUBMISSIONREQUEST']._serialized_end=4243
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v1/ledger_identity_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v1/ledger_identity_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4com/daml/ledger/api/v1/ledger_identity_service.proto\x12\x16\x63om.daml.ledger.api.v1\"\x1e\n\x18GetLedgerIdentityRequest:\x02\x18\x01\"@\n\x19GetLedgerIdentityResponse\x12\x1f\n\tledger_id\x18\x01 \x01(\tB\x02\x18\x01R\x08ledgerId:\x02\x18\x01\x32\x9b\x01\n\x15LedgerIdentityService\x12}\n\x11GetLedgerIdentity\x12\x30.com.daml.ledger.api.v1.GetLedgerIdentityRequest\x1a\x31.com.daml.ledger.api.v1.GetLedgerIdentityResponse\"\x03\x88\x02\x01\x1a\x03\x88\x02\x01\x42\x99\x01\n\x16\x63om.daml.ledger.api.v1B\x1fLedgerIdentityServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v1.ledger_identity_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v1B\037LedgerIdentityServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1'
  _globals['_GETLEDGERIDENTITYREQUEST']._loaded_options = None
  _globals['_GETLEDGERIDENTITYREQUEST']._serialized_options = b'\030\001'
  _globals['_GETLEDGERIDENTITYRESPONSE'].fields_by_name['ledger_id']._loaded_options = None
  _globals['_GETLEDGERIDENTITYRESPONSE'].fields_by_name['ledger_id']._serialized_options = b'\030\001'
  _globals['_GETLEDGERIDENTITYRESPONSE']._loaded_options = None
  _globals['_GETLEDGERIDENTITYRESPONSE']._serialized_options = b'\030\001'
  _globals['_LEDGERIDENTITYSERVICE']._loaded_options = None
  _globals['_LEDGERIDENTITYSERVICE']._serialized_options = b'\210\002\001'
  _globals['_LEDGERIDENTITYSERVICE'].methods_by_name['GetLedgerIdentity']._loaded_options = None
  _globals['_LEDGERIDENTITYSERVICE'].methods_by_name['GetLedgerIdentity']._serialized_options = b'\210\002\001'
  _globals['_GETLEDGERIDENTITYREQUEST']._serialized_start=80
  _globals['_GETLEDGERIDENTITYREQUEST']._serialized_end=110
  _globals['_GETLEDGERIDENTITYRESPONSE']._serialized_start=112
  _globals['_GETLEDGERIDENTITYRESPONSE']._serialized_end=176
  _globals['_LEDGERIDENTITYSERVICE']._serialized_start=179
  _globals['_LEDGERIDENTITYSERVICE']._serialized_end=334
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/daml_lf_1_16/daml_lf_1.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/daml_lf_1_16/daml_lf_1.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%com/daml/daml_lf_1_16/daml_lf_1.proto\x12\tdaml_lf_1\"\x06\n\x04Unit\"\x9b\x01\n\nPackageRef\x12%\n\x04self\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.UnitH\x00R\x04self\x12&\n\x0epackage_id_str\x18\x02 \x01(\tH\x00R\x0cpackageIdStr\x12\x37\n\x17package_id_interned_str\x18\x03 \x01(\x05H\x00R\x14packageIdInternedStrB\x05\n\x03Sum\"(\n\nDottedName\x12\x1a\n\x08segments\x18\x01 \x03(\tR\x08segments\"\xd6\x01\n\tModuleRef\x12\x36\n\x0bpackage_ref\x18\x01 \x01(\x0b\x32\x15.daml_lf_1.PackageRefR\npackageRef\x12\x43\n\x11module_name_dname\x18\x02 \x01(\x0b\x32\x15.daml_lf_1.DottedNameH\x00R\x0fmoduleNameDname\x12=\n\x1amodule_name_interned_dname\x18\x03 \x01(\x05H\x00R\x17moduleNameInternedDnameB\r\n\x0bmodule_name\"\xad\x01\n\x0bTypeConName\x12,\n\x06module\x18\x01 \x01(\x0b\x32\x14.daml_lf_1.ModuleRefR\x06module\x12\x36\n\nname_dname\x18\x02 \x01(\x0b\x32\x15.daml_lf_1.DottedNameH\x00R\tnameDname\x12\x30\n\x13name_interned_dname\x18\x03 \x01(\x05H\x00R\x11nameInternedDnameB\x06\n\x04name\"\xad\x01\n\x0bTypeSynName\x12,\n\x06module\x18\x01 \x01(\x0b\x32\x14.daml_lf_1.ModuleRefR\x06module\x12\x36\n\nname_dname\x18\x02 \x01(\x0b\x32\x15.daml_lf_1.DottedNameH\x00R\tnameDname\x12\x30\n\x13name_interned_dname\x18\x03 \x01(\x05H\x00R\x11nameInternedDnameB\x06\n\x04name\"\x86\x01\n\x07ValName\x12,\n\x06module\x18\x01 \x01(\x0b\x32\x14.daml_lf_1.ModuleRefR\x06module\x12\x1d\n\nname_dname\x18\x02 \x03(\tR\tnameDname\x12.\n\x13name_interned_dname\x18\x03 \x01(\x05R\x11nameInternedDname\"\x8c\x01\n\rFieldWithType\x12\x1d\n\tfield_str\x18\x01 \x01(\tH\x00R\x08\x66ieldStr\x12.\n\x12\x66ield_interned_str\x18\x03 \x01(\x05H\x00R\x10\x66ieldInternedStr\x12#\n\x04type\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04typeB\x07\n\x05\x66ield\"\x80\x01\n\x0bVarWithType\x12\x19\n\x07var_str\x18\x01 \x01(\tH\x00R\x06varStr\x12*\n\x10var_interned_str\x18\x03 \x01(\x05H\x00R\x0evarInternedStr\x12#\n\x04type\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04typeB\x05\n\x03var\"\x84\x01\n\x0fTypeVarWithKind\x12\x19\n\x07var_str\x18\x01 \x01(\tH\x00R\x06varStr\x12*\n\x10var_interned_str\x18\x03 \x01(\x05H\x00R\x0evarInternedStr\x12#\n\x04kind\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.KindR\x04kindB\x05\n\x03var\"\x8c\x01\n\rFieldWithExpr\x12\x1d\n\tfield_str\x18\x01 \x01(\tH\x00R\x08\x66ieldStr\x12.\n\x12\x66ield_interned_str\x18\x03 \x01(\x05H\x00R\x10\x66ieldInternedStr\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xprB\x07\n\x05\x66ield\"`\n\x07\x42inding\x12.\n\x06\x62inder\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.VarWithTypeR\x06\x62inder\x12%\n\x05\x62ound\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x05\x62ound\"\xe3\x01\n\x04Kind\x12%\n\x04star\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.UnitH\x00R\x04star\x12-\n\x05\x61rrow\x18\x02 \x01(\x0b\x32\x15.daml_lf_1.Kind.ArrowH\x00R\x05\x61rrow\x12#\n\x03nat\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.UnitH\x00R\x03nat\x1aY\n\x05\x41rrow\x12\'\n\x06params\x18\x01 \x03(\x0b\x32\x0f.daml_lf_1.KindR\x06params\x12\'\n\x06result\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.KindR\x06resultB\x05\n\x03Sum\"\x87\x07\n\x04Type\x12\'\n\x03var\x18\x01 \x01(\x0b\x32\x13.daml_lf_1.Type.VarH\x00R\x03var\x12\'\n\x03\x63on\x18\x02 \x01(\x0b\x32\x13.daml_lf_1.Type.ConH\x00R\x03\x63on\x12*\n\x04prim\x18\x03 \x01(\x0b\x32\x14.daml_lf_1.Type.PrimH\x00R\x04prim\x12\x30\n\x06\x66orall\x18\x05 \x01(\x0b\x32\x16.daml_lf_1.Type.ForallH\x00R\x06\x66orall\x12\x30\n\x06struct\x18\x07 \x01(\x0b\x32\x16.daml_lf_1.Type.StructH\x00R\x06struct\x12\x12\n\x03nat\x18\x0b \x01(\x12H\x00R\x03nat\x12\'\n\x03syn\x18\x0c \x01(\x0b\x32\x13.daml_lf_1.Type.SynH\x00R\x03syn\x12\x1c\n\x08interned\x18\r \x01(\x05H\x00R\x08interned\x1ax\n\x03Var\x12\x19\n\x07var_str\x18\x01 \x01(\tH\x00R\x06varStr\x12*\n\x10var_interned_str\x18\x03 \x01(\x05H\x00R\x0evarInternedStr\x12#\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x0f.daml_lf_1.TypeR\x04\x61rgsB\x05\n\x03var\x1aX\n\x03\x43on\x12,\n\x05tycon\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x05tycon\x12#\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x0f.daml_lf_1.TypeR\x04\x61rgs\x1aX\n\x03Syn\x12,\n\x05tysyn\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeSynNameR\x05tysyn\x12#\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x0f.daml_lf_1.TypeR\x04\x61rgs\x1aT\n\x04Prim\x12\'\n\x04prim\x18\x01 \x01(\x0e\x32\x13.daml_lf_1.PrimTypeR\x04prim\x12#\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x0f.daml_lf_1.TypeR\x04\x61rgs\x1a]\n\x06\x46orall\x12.\n\x04vars\x18\x01 \x03(\x0b\x32\x1a.daml_lf_1.TypeVarWithKindR\x04vars\x12#\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04\x62ody\x1a:\n\x06Struct\x12\x30\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x18.daml_lf_1.FieldWithTypeR\x06\x66ieldsB\x05\n\x03SumJ\x04\x08\x04\x10\x05J\x04\x08\x06\x10\x07J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"\x99\x04\n\x07PrimLit\x12\x16\n\x05int64\x18\x01 \x01(\x12H\x00R\x05int64\x12!\n\x0b\x64\x65\x63imal_str\x18\x02 \x01(\tH\x00R\ndecimalStr\x12\x32\n\x14numeric_interned_str\x18\n \x01(\x05H\x00R\x12numericInternedStr\x12\x1b\n\x08text_str\x18\x04 \x01(\tH\x00R\x07textStr\x12,\n\x11text_interned_str\x18\x0b \x01(\x05H\x00R\x0ftextInternedStr\x12\x1e\n\ttimestamp\x18\x05 \x01(\x10H\x00R\ttimestamp\x12\x1d\n\tparty_str\x18\x07 \x01(\tH\x00R\x08partyStr\x12.\n\x12party_interned_str\x18\x0c \x01(\x05H\x00R\x10partyInternedStr\x12\x14\n\x04\x64\x61te\x18\x08 \x01(\x05H\x00R\x04\x64\x61te\x12\x46\n\rrounding_mode\x18\r \x01(\x0e\x32\x1f.daml_lf_1.PrimLit.RoundingModeH\x00R\x0croundingMode\"t\n\x0cRoundingMode\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\x12\x0b\n\x07\x43\x45ILING\x10\x02\x12\t\n\x05\x46LOOR\x10\x03\x12\x0b\n\x07HALF_UP\x10\x04\x12\r\n\tHALF_DOWN\x10\x05\x12\r\n\tHALF_EVEN\x10\x06\x12\x0f\n\x0bUNNECESSARY\x10\x07\x42\x05\n\x03SumJ\x04\x08\x03\x10\x04J\x04\x08\x06\x10\x07\"\xe2\x01\n\x08Location\x12,\n\x06module\x18\x01 \x01(\x0b\x32\x14.daml_lf_1.ModuleRefR\x06module\x12/\n\x05range\x18\x02 \x01(\x0b\x32\x19.daml_lf_1.Location.RangeR\x05range\x1aw\n\x05Range\x12\x1d\n\nstart_line\x18\x01 \x01(\x05R\tstartLine\x12\x1b\n\tstart_col\x18\x02 \x01(\x05R\x08startCol\x12\x19\n\x08\x65nd_line\x18\x03 \x01(\x05R\x07\x65ndLine\x12\x17\n\x07\x65nd_col\x18\x04 \x01(\x05R\x06\x65ndCol\"\xdf=\n\x04\x45xpr\x12/\n\x08location\x18\x19 \x01(\x0b\x32\x13.daml_lf_1.LocationR\x08location\x12\x19\n\x07var_str\x18\x01 \x01(\tH\x00R\x06varStr\x12*\n\x10var_interned_str\x18\x1d \x01(\x05H\x00R\x0evarInternedStr\x12&\n\x03val\x18\x02 \x01(\x0b\x32\x12.daml_lf_1.ValNameH\x00R\x03val\x12\x36\n\x07\x62uiltin\x18\x03 \x01(\x0e\x32\x1a.daml_lf_1.BuiltinFunctionH\x00R\x07\x62uiltin\x12/\n\x08prim_con\x18\x04 \x01(\x0e\x32\x12.daml_lf_1.PrimConH\x00R\x07primCon\x12/\n\x08prim_lit\x18\x05 \x01(\x0b\x32\x12.daml_lf_1.PrimLitH\x00R\x07primLit\x12\x31\n\x07rec_con\x18\x06 \x01(\x0b\x32\x16.daml_lf_1.Expr.RecConH\x00R\x06recCon\x12\x34\n\x08rec_proj\x18\x07 \x01(\x0b\x32\x17.daml_lf_1.Expr.RecProjH\x00R\x07recProj\x12\x31\n\x07rec_upd\x18\x16 \x01(\x0b\x32\x16.daml_lf_1.Expr.RecUpdH\x00R\x06recUpd\x12=\n\x0bvariant_con\x18\x08 \x01(\x0b\x32\x1a.daml_lf_1.Expr.VariantConH\x00R\nvariantCon\x12\x34\n\x08\x65num_con\x18\x1c \x01(\x0b\x32\x17.daml_lf_1.Expr.EnumConH\x00R\x07\x65numCon\x12:\n\nstruct_con\x18\t \x01(\x0b\x32\x19.daml_lf_1.Expr.StructConH\x00R\tstructCon\x12=\n\x0bstruct_proj\x18\n \x01(\x0b\x32\x1a.daml_lf_1.Expr.StructProjH\x00R\nstructProj\x12:\n\nstruct_upd\x18\x17 \x01(\x0b\x32\x19.daml_lf_1.Expr.StructUpdH\x00R\tstructUpd\x12\'\n\x03\x61pp\x18\x0b \x01(\x0b\x32\x13.daml_lf_1.Expr.AppH\x00R\x03\x61pp\x12.\n\x06ty_app\x18\x0c \x01(\x0b\x32\x15.daml_lf_1.Expr.TyAppH\x00R\x05tyApp\x12\'\n\x03\x61\x62s\x18\r \x01(\x0b\x32\x13.daml_lf_1.Expr.AbsH\x00R\x03\x61\x62s\x12.\n\x06ty_abs\x18\x0e \x01(\x0b\x32\x15.daml_lf_1.Expr.TyAbsH\x00R\x05tyAbs\x12%\n\x04\x63\x61se\x18\x0f \x01(\x0b\x32\x0f.daml_lf_1.CaseH\x00R\x04\x63\x61se\x12$\n\x03let\x18\x10 \x01(\x0b\x32\x10.daml_lf_1.BlockH\x00R\x03let\x12\'\n\x03nil\x18\x11 \x01(\x0b\x32\x13.daml_lf_1.Expr.NilH\x00R\x03nil\x12*\n\x04\x63ons\x18\x12 \x01(\x0b\x32\x14.daml_lf_1.Expr.ConsH\x00R\x04\x63ons\x12+\n\x06update\x18\x14 \x01(\x0b\x32\x11.daml_lf_1.UpdateH\x00R\x06update\x12\x31\n\x08scenario\x18\x15 \x01(\x0b\x32\x13.daml_lf_1.ScenarioH\x00R\x08scenario\x12\x43\n\roptional_none\x18\x1a \x01(\x0b\x32\x1c.daml_lf_1.Expr.OptionalNoneH\x00R\x0coptionalNone\x12\x43\n\roptional_some\x18\x1b \x01(\x0b\x32\x1c.daml_lf_1.Expr.OptionalSomeH\x00R\x0coptionalSome\x12.\n\x06to_any\x18\x1e \x01(\x0b\x32\x15.daml_lf_1.Expr.ToAnyH\x00R\x05toAny\x12\x34\n\x08\x66rom_any\x18\x1f \x01(\x0b\x32\x17.daml_lf_1.Expr.FromAnyH\x00R\x07\x66romAny\x12,\n\x08type_rep\x18  \x01(\x0b\x32\x0f.daml_lf_1.TypeH\x00R\x07typeRep\x12J\n\x10to_any_exception\x18! \x01(\x0b\x32\x1e.daml_lf_1.Expr.ToAnyExceptionH\x00R\x0etoAnyException\x12P\n\x12\x66rom_any_exception\x18\" \x01(\x0b\x32 .daml_lf_1.Expr.FromAnyExceptionH\x00R\x10\x66romAnyException\x12-\n\x05throw\x18# \x01(\x0b\x32\x15.daml_lf_1.Expr.ThrowH\x00R\x05throw\x12@\n\x0cto_interface\x18$ \x01(\x0b\x32\x1b.daml_lf_1.Expr.ToInterfaceH\x00R\x0btoInterface\x12\x46\n\x0e\x66rom_interface\x18% \x01(\x0b\x32\x1d.daml_lf_1.Expr.FromInterfaceH\x00R\rfromInterface\x12\x46\n\x0e\x63\x61ll_interface\x18& \x01(\x0b\x32\x1d.daml_lf_1.Expr.CallInterfaceH\x00R\rcallInterface\x12U\n\x13signatory_interface\x18\' \x01(\x0b\x32\".daml_lf_1.Expr.SignatoryInterfaceH\x00R\x12signatoryInterface\x12R\n\x12observer_interface\x18( \x01(\x0b\x32!.daml_lf_1.Expr.ObserverInterfaceH\x00R\x11observerInterface\x12\x46\n\x0eview_interface\x18) \x01(\x0b\x32\x1d.daml_lf_1.Expr.ViewInterfaceH\x00R\rviewInterface\x12Y\n\x15unsafe_from_interface\x18* \x01(\x0b\x32#.daml_lf_1.Expr.UnsafeFromInterfaceH\x00R\x13unsafeFromInterface\x12i\n\x1binterface_template_type_rep\x18+ \x01(\x0b\x32(.daml_lf_1.Expr.InterfaceTemplateTypeRepH\x00R\x18interfaceTemplateTypeRep\x12Y\n\x15to_required_interface\x18, \x01(\x0b\x32#.daml_lf_1.Expr.ToRequiredInterfaceH\x00R\x13toRequiredInterface\x12_\n\x17\x66rom_required_interface\x18- \x01(\x0b\x32%.daml_lf_1.Expr.FromRequiredInterfaceH\x00R\x15\x66romRequiredInterface\x12r\n\x1eunsafe_from_required_interface\x18. \x01(\x0b\x32+.daml_lf_1.Expr.UnsafeFromRequiredInterfaceH\x00R\x1bunsafeFromRequiredInterface\x12O\n\x11\x63hoice_controller\x18/ \x01(\x0b\x32 .daml_lf_1.Expr.ChoiceControllerH\x00R\x10\x63hoiceController\x12I\n\x0f\x63hoice_observer\x18\x30 \x01(\x0b\x32\x1e.daml_lf_1.Expr.ChoiceObserverH\x00R\x0e\x63hoiceObserver\x12\x43\n\x0c\x65xperimental\x18\x8fN \x01(\x0b\x32\x1c.daml_lf_1.Expr.ExperimentalH\x00R\x0c\x65xperimental\x1a\x65\n\x06RecCon\x12)\n\x05tycon\x18\x01 \x01(\x0b\x32\x13.daml_lf_1.Type.ConR\x05tycon\x12\x30\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x18.daml_lf_1.FieldWithExprR\x06\x66ields\x1a\xb5\x01\n\x07RecProj\x12)\n\x05tycon\x18\x01 \x01(\x0b\x32\x13.daml_lf_1.Type.ConR\x05tycon\x12\x1d\n\tfield_str\x18\x02 \x01(\tH\x00R\x08\x66ieldStr\x12.\n\x12\x66ield_interned_str\x18\x04 \x01(\x05H\x00R\x10\x66ieldInternedStr\x12\'\n\x06record\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x06recordB\x07\n\x05\x66ield\x1a\xdd\x01\n\x06RecUpd\x12)\n\x05tycon\x18\x01 \x01(\x0b\x32\x13.daml_lf_1.Type.ConR\x05tycon\x12\x1d\n\tfield_str\x18\x02 \x01(\tH\x00R\x08\x66ieldStr\x12.\n\x12\x66ield_interned_str\x18\x05 \x01(\x05H\x00R\x10\x66ieldInternedStr\x12\'\n\x06record\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x06record\x12\'\n\x06update\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x06updateB\x07\n\x05\x66ield\x1a\xdd\x01\n\nVariantCon\x12)\n\x05tycon\x18\x01 \x01(\x0b\x32\x13.daml_lf_1.Type.ConR\x05tycon\x12(\n\x0fvariant_con_str\x18\x02 \x01(\tH\x00R\rvariantConStr\x12\x39\n\x18variant_con_interned_str\x18\x04 \x01(\x05H\x00R\x15variantConInternedStr\x12\x30\n\x0bvariant_arg\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\nvariantArgB\r\n\x0bvariant_con\x1a\x9c\x01\n\x07\x45numCon\x12,\n\x05tycon\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x05tycon\x12\"\n\x0c\x65num_con_str\x18\x02 \x01(\tH\x00R\nenumConStr\x12\x33\n\x15\x65num_con_interned_str\x18\x03 \x01(\x05H\x00R\x12\x65numConInternedStrB\n\n\x08\x65num_con\x1a=\n\tStructCon\x12\x30\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x18.daml_lf_1.FieldWithExprR\x06\x66ields\x1a\x8d\x01\n\nStructProj\x12\x1d\n\tfield_str\x18\x01 \x01(\tH\x00R\x08\x66ieldStr\x12.\n\x12\x66ield_interned_str\x18\x03 \x01(\x05H\x00R\x10\x66ieldInternedStr\x12\'\n\x06struct\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x06structB\x07\n\x05\x66ield\x1a\xb5\x01\n\tStructUpd\x12\x1d\n\tfield_str\x18\x01 \x01(\tH\x00R\x08\x66ieldStr\x12.\n\x12\x66ield_interned_str\x18\x04 \x01(\x05H\x00R\x10\x66ieldInternedStr\x12\'\n\x06struct\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x06struct\x12\'\n\x06update\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x06updateB\x07\n\x05\x66ield\x1aM\n\x03\x41pp\x12!\n\x03\x66un\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x03\x66un\x12#\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x61rgs\x1aS\n\x05TyApp\x12#\n\x04\x65xpr\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xpr\x12%\n\x05types\x18\x02 \x03(\x0b\x32\x0f.daml_lf_1.TypeR\x05types\x1aX\n\x03\x41\x62s\x12,\n\x05param\x18\x01 \x03(\x0b\x32\x16.daml_lf_1.VarWithTypeR\x05param\x12#\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x62ody\x1a^\n\x05TyAbs\x12\x30\n\x05param\x18\x01 \x03(\x0b\x32\x1a.daml_lf_1.TypeVarWithKindR\x05param\x12#\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x62ody\x1a*\n\x03Nil\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04type\x1aw\n\x04\x43ons\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04type\x12%\n\x05\x66ront\x18\x02 \x03(\x0b\x32\x0f.daml_lf_1.ExprR\x05\x66ront\x12#\n\x04tail\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04tail\x1a\x33\n\x0cOptionalNone\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04type\x1aX\n\x0cOptionalSome\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04type\x12#\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x62ody\x1aQ\n\x05ToAny\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04type\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xpr\x1aS\n\x07\x46romAny\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04type\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xpr\x1aZ\n\x0eToAnyException\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04type\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xpr\x1a\\\n\x10\x46romAnyException\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04type\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xpr\x1a\xa9\x01\n\x05Throw\x12\x30\n\x0breturn_type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\nreturnType\x12\x36\n\x0e\x65xception_type\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\rexceptionType\x12\x36\n\x0e\x65xception_expr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\rexceptionExpr\x1a\xbf\x01\n\x0bToInterface\x12=\n\x0einterface_type\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\rinterfaceType\x12;\n\rtemplate_type\x18\x02 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x0ctemplateType\x12\x34\n\rtemplate_expr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x0ctemplateExpr\x1a\xc3\x01\n\rFromInterface\x12=\n\x0einterface_type\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\rinterfaceType\x12;\n\rtemplate_type\x18\x02 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x0ctemplateType\x12\x36\n\x0einterface_expr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\rinterfaceExpr\x1a\xb8\x01\n\rCallInterface\x12=\n\x0einterface_type\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\rinterfaceType\x12\x30\n\x14method_interned_name\x18\x02 \x01(\x05R\x12methodInternedName\x12\x36\n\x0einterface_expr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\rinterfaceExpr\x1aj\n\rViewInterface\x12\x34\n\tinterface\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\tinterface\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xpr\x1ao\n\x12SignatoryInterface\x12\x34\n\tinterface\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\tinterface\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xpr\x1an\n\x11ObserverInterface\x12\x34\n\tinterface\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\tinterface\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xpr\x1a\x84\x02\n\x13UnsafeFromInterface\x12=\n\x0einterface_type\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\rinterfaceType\x12;\n\rtemplate_type\x18\x02 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x0ctemplateType\x12\x39\n\x10\x63ontract_id_expr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x0e\x63ontractIdExpr\x12\x36\n\x0einterface_expr\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\rinterfaceExpr\x1a\xca\x01\n\x13ToRequiredInterface\x12\x45\n\x12required_interface\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x11requiredInterface\x12G\n\x13requiring_interface\x18\x02 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x12requiringInterface\x12#\n\x04\x65xpr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xpr\x1a\xcc\x01\n\x15\x46romRequiredInterface\x12\x45\n\x12required_interface\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x11requiredInterface\x12G\n\x13requiring_interface\x18\x02 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x12requiringInterface\x12#\n\x04\x65xpr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xpr\x1a\xa0\x02\n\x1bUnsafeFromRequiredInterface\x12\x45\n\x12required_interface\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x11requiredInterface\x12G\n\x13requiring_interface\x18\x02 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x12requiringInterface\x12\x39\n\x10\x63ontract_id_expr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x0e\x63ontractIdExpr\x12\x36\n\x0einterface_expr\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\rinterfaceExpr\x1au\n\x18InterfaceTemplateTypeRep\x12\x34\n\tinterface\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\tinterface\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xpr\x1a\xe5\x01\n\x10\x43hoiceController\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x08template\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12\x34\n\rcontract_expr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x0c\x63ontractExpr\x12\x37\n\x0f\x63hoice_arg_expr\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\rchoiceArgExpr\x1a\xe3\x01\n\x0e\x43hoiceObserver\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x08template\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12\x34\n\rcontract_expr\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x0c\x63ontractExpr\x12\x37\n\x0f\x63hoice_arg_expr\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\rchoiceArgExpr\x1aG\n\x0c\x45xperimental\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12#\n\x04type\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04typeB\x05\n\x03SumJ\x04\x08\x13\x10\x14J\x04\x08\x18\x10\x19\"\xb4\t\n\x07\x43\x61seAlt\x12+\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.UnitH\x00R\x07\x64\x65\x66\x61ult\x12\x36\n\x07variant\x18\x02 \x01(\x0b\x32\x1a.daml_lf_1.CaseAlt.VariantH\x00R\x07variant\x12/\n\x08prim_con\x18\x03 \x01(\x0e\x32\x12.daml_lf_1.PrimConH\x00R\x07primCon\x12#\n\x03nil\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.UnitH\x00R\x03nil\x12-\n\x04\x63ons\x18\x05 \x01(\x0b\x32\x17.daml_lf_1.CaseAlt.ConsH\x00R\x04\x63ons\x12\x36\n\roptional_none\x18\x07 \x01(\x0b\x32\x0f.daml_lf_1.UnitH\x00R\x0coptionalNone\x12\x46\n\roptional_some\x18\x08 \x01(\x0b\x32\x1f.daml_lf_1.CaseAlt.OptionalSomeH\x00R\x0coptionalSome\x12-\n\x04\x65num\x18\t \x01(\x0b\x32\x17.daml_lf_1.CaseAlt.EnumH\x00R\x04\x65num\x12#\n\x04\x62ody\x18\x06 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x62ody\x1a\xf2\x01\n\x07Variant\x12(\n\x03\x63on\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x03\x63on\x12!\n\x0bvariant_str\x18\x02 \x01(\tH\x00R\nvariantStr\x12\x32\n\x14variant_interned_str\x18\x04 \x01(\x05H\x00R\x12variantInternedStr\x12\x1f\n\nbinder_str\x18\x03 \x01(\tH\x01R\tbinderStr\x12\x30\n\x13\x62inder_interned_str\x18\x05 \x01(\x05H\x01R\x11\x62inderInternedStrB\t\n\x07variantB\x08\n\x06\x62inder\x1a\xa6\x01\n\x04\x45num\x12(\n\x03\x63on\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x03\x63on\x12)\n\x0f\x63onstructor_str\x18\x02 \x01(\tH\x00R\x0e\x63onstructorStr\x12:\n\x18\x63onstructor_interned_str\x18\x03 \x01(\x05H\x00R\x16\x63onstructorInternedStrB\r\n\x0b\x63onstructor\x1a\xd0\x01\n\x04\x43ons\x12\"\n\x0cvar_head_str\x18\x01 \x01(\tH\x00R\nvarHeadStr\x12\x33\n\x15var_head_interned_str\x18\x03 \x01(\x05H\x00R\x12varHeadInternedStr\x12\"\n\x0cvar_tail_str\x18\x02 \x01(\tH\x01R\nvarTailStr\x12\x33\n\x15var_tail_interned_str\x18\x04 \x01(\x05H\x01R\x12varTailInternedStrB\n\n\x08var_headB\n\n\x08var_tail\x1as\n\x0cOptionalSome\x12\"\n\x0cvar_body_str\x18\x01 \x01(\tH\x00R\nvarBodyStr\x12\x33\n\x15var_body_interned_str\x18\x02 \x01(\x05H\x00R\x12varBodyInternedStrB\n\n\x08var_bodyB\x05\n\x03Sum\"U\n\x04\x43\x61se\x12%\n\x05scrut\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x05scrut\x12&\n\x04\x61lts\x18\x02 \x03(\x0b\x32\x12.daml_lf_1.CaseAltR\x04\x61lts\"\\\n\x05\x42lock\x12.\n\x08\x62indings\x18\x01 \x03(\x0b\x32\x12.daml_lf_1.BindingR\x08\x62indings\x12#\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x62ody\"P\n\x04Pure\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04type\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xpr\"\x84\x18\n\x06Update\x12%\n\x04pure\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.PureH\x00R\x04pure\x12(\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x10.daml_lf_1.BlockH\x00R\x05\x62lock\x12\x32\n\x06\x63reate\x18\x03 \x01(\x0b\x32\x18.daml_lf_1.Update.CreateH\x00R\x06\x63reate\x12\x38\n\x08\x65xercise\x18\x04 \x01(\x0b\x32\x1a.daml_lf_1.Update.ExerciseH\x00R\x08\x65xercise\x12I\n\x0f\x65xercise_by_key\x18\n \x01(\x0b\x32\x1f.daml_lf_1.Update.ExerciseByKeyH\x00R\rexerciseByKey\x12/\n\x05\x66\x65tch\x18\x05 \x01(\x0b\x32\x17.daml_lf_1.Update.FetchH\x00R\x05\x66\x65tch\x12,\n\x08get_time\x18\x06 \x01(\x0b\x32\x0f.daml_lf_1.UnitH\x00R\x07getTime\x12\x45\n\rlookup_by_key\x18\x08 \x01(\x0b\x32\x1f.daml_lf_1.Update.RetrieveByKeyH\x00R\x0blookupByKey\x12\x43\n\x0c\x66\x65tch_by_key\x18\t \x01(\x0b\x32\x1f.daml_lf_1.Update.RetrieveByKeyH\x00R\nfetchByKey\x12<\n\nembed_expr\x18\x07 \x01(\x0b\x32\x1b.daml_lf_1.Update.EmbedExprH\x00R\tembedExpr\x12\x39\n\ttry_catch\x18\x0b \x01(\x0b\x32\x1a.daml_lf_1.Update.TryCatchH\x00R\x08tryCatch\x12N\n\x10\x63reate_interface\x18\x0c \x01(\x0b\x32!.daml_lf_1.Update.CreateInterfaceH\x00R\x0f\x63reateInterface\x12T\n\x12\x65xercise_interface\x18\r \x01(\x0b\x32#.daml_lf_1.Update.ExerciseInterfaceH\x00R\x11\x65xerciseInterface\x12K\n\x0f\x66\x65tch_interface\x18\x0e \x01(\x0b\x32 .daml_lf_1.Update.FetchInterfaceH\x00R\x0e\x66\x65tchInterface\x12N\n\x10\x64ynamic_exercise\x18\x0f \x01(\x0b\x32!.daml_lf_1.Update.DynamicExerciseH\x00R\x0f\x64ynamicExercise\x12<\n\nsoft_fetch\x18\x10 \x01(\x0b\x32\x1b.daml_lf_1.Update.SoftFetchH\x00R\tsoftFetch\x12\x45\n\rsoft_exercise\x18\x11 \x01(\x0b\x32\x1e.daml_lf_1.Update.SoftExerciseH\x00R\x0csoftExercise\x1a\x61\n\x06\x43reate\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x08template\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xpr\x1al\n\x0f\x43reateInterface\x12\x34\n\tinterface\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\tinterface\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xpr\x1a\xe7\x01\n\x08\x45xercise\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x08template\x12\x1f\n\nchoice_str\x18\x02 \x01(\tH\x00R\tchoiceStr\x12\x30\n\x13\x63hoice_interned_str\x18\x06 \x01(\x05H\x00R\x11\x63hoiceInternedStr\x12!\n\x03\x63id\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x03\x63id\x12!\n\x03\x61rg\x18\x05 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x03\x61rgB\x08\n\x06\x63hoiceJ\x04\x08\x04\x10\x05\x1a\xe5\x01\n\x0cSoftExercise\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x08template\x12\x1f\n\nchoice_str\x18\x02 \x01(\tH\x00R\tchoiceStr\x12\x30\n\x13\x63hoice_interned_str\x18\x06 \x01(\x05H\x00R\x11\x63hoiceInternedStr\x12!\n\x03\x63id\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x03\x63id\x12!\n\x03\x61rg\x18\x05 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x03\x61rgB\x08\n\x06\x63hoice\x1a\xbb\x01\n\x0f\x44ynamicExercise\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x08template\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12!\n\x03\x63id\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x03\x63id\x12!\n\x03\x61rg\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x03\x61rg\x1a\xe6\x01\n\x11\x45xerciseInterface\x12\x34\n\tinterface\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\tinterface\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12!\n\x03\x63id\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x03\x63id\x12!\n\x03\x61rg\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x03\x61rg\x12%\n\x05guard\x18\x05 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x05guard\x1a\xb9\x01\n\rExerciseByKey\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x08template\x12.\n\x13\x63hoice_interned_str\x18\x02 \x01(\x05R\x11\x63hoiceInternedStr\x12!\n\x03key\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x03key\x12!\n\x03\x61rg\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x03\x61rg\x1a\x64\n\x05\x46\x65tch\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x08template\x12!\n\x03\x63id\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x03\x63idJ\x04\x08\x03\x10\x04\x1a\x62\n\tSoftFetch\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x08template\x12!\n\x03\x63id\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x03\x63id\x1ai\n\x0e\x46\x65tchInterface\x12\x34\n\tinterface\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\tinterface\x12!\n\x03\x63id\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x03\x63id\x1aU\n\tEmbedExpr\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04type\x12#\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x62ody\x1a\x66\n\rRetrieveByKey\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x08template\x12!\n\x03key\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x03key\x1a\xc2\x01\n\x08TryCatch\x12\x30\n\x0breturn_type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\nreturnType\x12*\n\x08try_expr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x07tryExpr\x12(\n\x10var_interned_str\x18\x03 \x01(\x05R\x0evarInternedStr\x12.\n\ncatch_expr\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\tcatchExprB\x05\n\x03Sum\"\xf5\x04\n\x08Scenario\x12%\n\x04pure\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.PureH\x00R\x04pure\x12(\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x10.daml_lf_1.BlockH\x00R\x05\x62lock\x12\x34\n\x06\x63ommit\x18\x03 \x01(\x0b\x32\x1a.daml_lf_1.Scenario.CommitH\x00R\x06\x63ommit\x12<\n\nmustFailAt\x18\x04 \x01(\x0b\x32\x1a.daml_lf_1.Scenario.CommitH\x00R\nmustFailAt\x12%\n\x04pass\x18\x05 \x01(\x0b\x32\x0f.daml_lf_1.ExprH\x00R\x04pass\x12,\n\x08get_time\x18\x06 \x01(\x0b\x32\x0f.daml_lf_1.UnitH\x00R\x07getTime\x12.\n\tget_party\x18\x07 \x01(\x0b\x32\x0f.daml_lf_1.ExprH\x00R\x08getParty\x12>\n\nembed_expr\x18\x08 \x01(\x0b\x32\x1d.daml_lf_1.Scenario.EmbedExprH\x00R\tembedExpr\x1a\x80\x01\n\x06\x43ommit\x12%\n\x05party\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x05party\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xpr\x12*\n\x08ret_type\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x07retType\x1aU\n\tEmbedExpr\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04type\x12#\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x62odyB\x05\n\x03Sum\"\xc7\x04\n\x0eTemplateChoice\x12\x1b\n\x08name_str\x18\x01 \x01(\tH\x00R\x07nameStr\x12,\n\x11name_interned_str\x18\t \x01(\x05H\x00R\x0fnameInternedStr\x12\x1c\n\tconsuming\x18\x02 \x01(\x08R\tconsuming\x12\x31\n\x0b\x63ontrollers\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x0b\x63ontrollers\x12-\n\tobservers\x18\x0b \x01(\x0b\x32\x0f.daml_lf_1.ExprR\tobservers\x12\x31\n\x0b\x61uthorizers\x18\x0c \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x0b\x61uthorizers\x12\x35\n\narg_binder\x18\x04 \x01(\x0b\x32\x16.daml_lf_1.VarWithTypeR\targBinder\x12*\n\x08ret_type\x18\x05 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x07retType\x12\'\n\x06update\x18\x06 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x06update\x12(\n\x0fself_binder_str\x18\x07 \x01(\tH\x01R\rselfBinderStr\x12\x39\n\x18self_binder_interned_str\x18\n \x01(\x05H\x01R\x15selfBinderInternedStr\x12/\n\x08location\x18\x08 \x01(\x0b\x32\x13.daml_lf_1.LocationR\x08locationB\x06\n\x04nameB\r\n\x0bself_binder\"\xe8\x04\n\x07KeyExpr\x12\x42\n\x0bprojections\x18\x01 \x01(\x0b\x32\x1e.daml_lf_1.KeyExpr.ProjectionsH\x00R\x0bprojections\x12\x33\n\x06record\x18\x02 \x01(\x0b\x32\x19.daml_lf_1.KeyExpr.RecordH\x00R\x06record\x1a\x8f\x01\n\nProjection\x12)\n\x05tycon\x18\x01 \x01(\x0b\x32\x13.daml_lf_1.Type.ConR\x05tycon\x12\x1d\n\tfield_str\x18\x02 \x01(\tH\x00R\x08\x66ieldStr\x12.\n\x12\x66ield_interned_str\x18\x03 \x01(\x05H\x00R\x10\x66ieldInternedStrB\x07\n\x05\x66ield\x1aN\n\x0bProjections\x12?\n\x0bprojections\x18\x02 \x03(\x0b\x32\x1d.daml_lf_1.KeyExpr.ProjectionR\x0bprojections\x1a\x8d\x01\n\x0bRecordField\x12\x1d\n\tfield_str\x18\x01 \x01(\tH\x00R\x08\x66ieldStr\x12.\n\x12\x66ield_interned_str\x18\x03 \x01(\x05H\x00R\x10\x66ieldInternedStr\x12&\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x12.daml_lf_1.KeyExprR\x04\x65xprB\x07\n\x05\x66ield\x1ak\n\x06Record\x12)\n\x05tycon\x18\x01 \x01(\x0b\x32\x13.daml_lf_1.Type.ConR\x05tycon\x12\x36\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x1e.daml_lf_1.KeyExpr.RecordFieldR\x06\x66ieldsB\x05\n\x03Sum\"\x84\x02\n\x15InterfaceInstanceBody\x12R\n\x07methods\x18\x01 \x03(\x0b\x32\x38.daml_lf_1.InterfaceInstanceBody.InterfaceInstanceMethodR\x07methods\x12#\n\x04view\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04view\x1ar\n\x17InterfaceInstanceMethod\x12\x30\n\x14method_interned_name\x18\x01 \x01(\x05R\x12methodInternedName\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x05value\"\xef\x07\n\x0b\x44\x65\x66Template\x12\x38\n\x0btycon_dname\x18\x01 \x01(\x0b\x32\x15.daml_lf_1.DottedNameH\x00R\ntyconDname\x12\x32\n\x14tycon_interned_dname\x18\x0c \x01(\x05H\x00R\x12tyconInternedDname\x12\x1d\n\tparam_str\x18\x02 \x01(\tH\x01R\x08paramStr\x12.\n\x12param_interned_str\x18\x0b \x01(\x05H\x01R\x10paramInternedStr\x12)\n\x07precond\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x07precond\x12\x31\n\x0bsignatories\x18\x05 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x0bsignatories\x12-\n\tagreement\x18\x06 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\tagreement\x12\x33\n\x07\x63hoices\x18\x07 \x03(\x0b\x32\x19.daml_lf_1.TemplateChoiceR\x07\x63hoices\x12-\n\tobservers\x18\x08 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\tobservers\x12/\n\x08location\x18\t \x01(\x0b\x32\x13.daml_lf_1.LocationR\x08location\x12/\n\x03key\x18\n \x01(\x0b\x32\x1d.daml_lf_1.DefTemplate.DefKeyR\x03key\x12\x41\n\nimplements\x18\r \x03(\x0b\x32!.daml_lf_1.DefTemplate.ImplementsR\nimplements\x1a\xc8\x01\n\x06\x44\x65\x66Key\x12#\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04type\x12&\n\x03key\x18\x02 \x01(\x0b\x32\x12.daml_lf_1.KeyExprH\x00R\x03key\x12\x32\n\x0b\x63omplex_key\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.ExprH\x00R\ncomplexKey\x12\x31\n\x0bmaintainers\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x0bmaintainersB\n\n\x08key_expr\x1a\xa9\x01\n\nImplements\x12\x34\n\tinterface\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\tinterface\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32 .daml_lf_1.InterfaceInstanceBodyR\x04\x62ody\x12/\n\x08location\x18\x03 \x01(\x0b\x32\x13.daml_lf_1.LocationR\x08locationB\x07\n\x05tyconB\x07\n\x05paramJ\x04\x08\x03\x10\x04\"\x99\x01\n\x0fInterfaceMethod\x12/\n\x08location\x18\x01 \x01(\x0b\x32\x13.daml_lf_1.LocationR\x08location\x12\x30\n\x14method_interned_name\x18\x02 \x01(\x05R\x12methodInternedName\x12#\n\x04type\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04type\"\xd9\x04\n\x0c\x44\x65\x66Interface\x12/\n\x08location\x18\x01 \x01(\x0b\x32\x13.daml_lf_1.LocationR\x08location\x12\x30\n\x14tycon_interned_dname\x18\x02 \x01(\x05R\x12tyconInternedDname\x12\x34\n\x07methods\x18\x03 \x03(\x0b\x32\x1a.daml_lf_1.InterfaceMethodR\x07methods\x12,\n\x12param_interned_str\x18\x04 \x01(\x05R\x10paramInternedStr\x12\x33\n\x07\x63hoices\x18\x05 \x03(\x0b\x32\x19.daml_lf_1.TemplateChoiceR\x07\x63hoices\x12H\n\x0c\x63oImplements\x18\x06 \x03(\x0b\x32$.daml_lf_1.DefInterface.CoImplementsR\x0c\x63oImplements\x12#\n\x04view\x18\x08 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04view\x12\x32\n\x08requires\x18\t \x03(\x0b\x32\x16.daml_lf_1.TypeConNameR\x08requires\x1a\xa9\x01\n\x0c\x43oImplements\x12\x32\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConNameR\x08template\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32 .daml_lf_1.InterfaceInstanceBodyR\x04\x62ody\x12/\n\x08location\x18\x03 \x01(\x0b\x32\x13.daml_lf_1.LocationR\x08location\"\x9a\x01\n\x0c\x44\x65\x66\x45xception\x12.\n\x13name_interned_dname\x18\x01 \x01(\x05R\x11nameInternedDname\x12/\n\x08location\x18\x02 \x01(\x0b\x32\x13.daml_lf_1.LocationR\x08location\x12)\n\x07message\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x07message\"\xaf\x05\n\x0b\x44\x65\x66\x44\x61taType\x12\x36\n\nname_dname\x18\x01 \x01(\x0b\x32\x15.daml_lf_1.DottedNameH\x00R\tnameDname\x12\x30\n\x13name_interned_dname\x18\x08 \x01(\x05H\x00R\x11nameInternedDname\x12\x32\n\x06params\x18\x02 \x03(\x0b\x32\x1a.daml_lf_1.TypeVarWithKindR\x06params\x12\x37\n\x06record\x18\x03 \x01(\x0b\x32\x1d.daml_lf_1.DefDataType.FieldsH\x01R\x06record\x12\x39\n\x07variant\x18\x04 \x01(\x0b\x32\x1d.daml_lf_1.DefDataType.FieldsH\x01R\x07variant\x12=\n\x04\x65num\x18\x07 \x01(\x0b\x32\'.daml_lf_1.DefDataType.EnumConstructorsH\x01R\x04\x65num\x12/\n\tinterface\x18\t \x01(\x0b\x32\x0f.daml_lf_1.UnitH\x01R\tinterface\x12\"\n\x0cserializable\x18\x05 \x01(\x08R\x0cserializable\x12/\n\x08location\x18\x06 \x01(\x0b\x32\x13.daml_lf_1.LocationR\x08location\x1a:\n\x06\x46ields\x12\x30\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x18.daml_lf_1.FieldWithTypeR\x06\x66ields\x1ay\n\x10\x45numConstructors\x12)\n\x10\x63onstructors_str\x18\x01 \x03(\tR\x0f\x63onstructorsStr\x12:\n\x19\x63onstructors_interned_str\x18\x02 \x03(\x05R\x17\x63onstructorsInternedStrB\x06\n\x04nameB\n\n\x08\x44\x61taCons\"\x88\x02\n\nDefTypeSyn\x12\x36\n\nname_dname\x18\x01 \x01(\x0b\x32\x15.daml_lf_1.DottedNameH\x00R\tnameDname\x12\x30\n\x13name_interned_dname\x18\x08 \x01(\x05H\x00R\x11nameInternedDname\x12\x32\n\x06params\x18\x02 \x03(\x0b\x32\x1a.daml_lf_1.TypeVarWithKindR\x06params\x12#\n\x04type\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04type\x12/\n\x08location\x18\x04 \x01(\x0b\x32\x13.daml_lf_1.LocationR\x08locationB\x06\n\x04name\"\xf2\x02\n\x08\x44\x65\x66Value\x12\x46\n\x0ename_with_type\x18\x01 \x01(\x0b\x32 .daml_lf_1.DefValue.NameWithTypeR\x0cnameWithType\x12#\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprR\x04\x65xpr\x12*\n\x11no_party_literals\x18\x03 \x01(\x08R\x0fnoPartyLiterals\x12\x17\n\x07is_test\x18\x04 \x01(\x08R\x06isTest\x12/\n\x08location\x18\x05 \x01(\x0b\x32\x13.daml_lf_1.LocationR\x08location\x1a\x82\x01\n\x0cNameWithType\x12\x1d\n\nname_dname\x18\x01 \x03(\tR\tnameDname\x12.\n\x13name_interned_dname\x18\x03 \x01(\x05R\x11nameInternedDname\x12#\n\x04type\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.TypeR\x04type\"\xfa\x01\n\x0c\x46\x65\x61tureFlags\x12\x30\n\x13\x66orbidPartyLiterals\x18\x01 \x01(\x08R\x13\x66orbidPartyLiterals\x12X\n\'dontDivulgeContractIdsInCreateArguments\x18\x02 \x01(\x08R\'dontDivulgeContractIdsInCreateArguments\x12^\n*dontDiscloseNonConsumingChoicesToObservers\x18\x03 \x01(\x08R*dontDiscloseNonConsumingChoicesToObservers\"\xf4\x03\n\x06Module\x12\x36\n\nname_dname\x18\x01 \x01(\x0b\x32\x15.daml_lf_1.DottedNameH\x00R\tnameDname\x12\x30\n\x13name_interned_dname\x18\x08 \x01(\x05H\x00R\x11nameInternedDname\x12-\n\x05\x66lags\x18\x04 \x01(\x0b\x32\x17.daml_lf_1.FeatureFlagsR\x05\x66lags\x12\x31\n\x08synonyms\x18\t \x03(\x0b\x32\x15.daml_lf_1.DefTypeSynR\x08synonyms\x12\x35\n\ndata_types\x18\x05 \x03(\x0b\x32\x16.daml_lf_1.DefDataTypeR\tdataTypes\x12+\n\x06values\x18\x06 \x03(\x0b\x32\x13.daml_lf_1.DefValueR\x06values\x12\x34\n\ttemplates\x18\x07 \x03(\x0b\x32\x16.daml_lf_1.DefTemplateR\ttemplates\x12\x37\n\nexceptions\x18\n \x03(\x0b\x32\x17.daml_lf_1.DefExceptionR\nexceptions\x12\x37\n\ninterfaces\x18\x0b \x03(\x0b\x32\x17.daml_lf_1.DefInterfaceR\ninterfacesB\x06\n\x04nameJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"H\n\x12InternedDottedName\x12\x32\n\x15segments_interned_str\x18\x01 \x03(\x05R\x13segmentsInternedStr\"[\n\x11UpgradedPackageId\x12\x46\n upgraded_package_id_interned_str\x18\x01 \x01(\x05R\x1cupgradedPackageIdInternedStr\"\xbd\x01\n\x0fPackageMetadata\x12*\n\x11name_interned_str\x18\x01 \x01(\x05R\x0fnameInternedStr\x12\x30\n\x14version_interned_str\x18\x02 \x01(\x05R\x12versionInternedStr\x12L\n\x13upgraded_package_id\x18\x03 \x01(\x0b\x32\x1c.daml_lf_1.UpgradedPackageIdR\x11upgradedPackageId\"\xa4\x02\n\x07Package\x12+\n\x07modules\x18\x01 \x03(\x0b\x32\x11.daml_lf_1.ModuleR\x07modules\x12)\n\x10interned_strings\x18\x02 \x03(\tR\x0finternedStrings\x12Q\n\x15interned_dotted_names\x18\x03 \x03(\x0b\x32\x1d.daml_lf_1.InternedDottedNameR\x13internedDottedNames\x12\x36\n\x08metadata\x18\x04 \x01(\x0b\x32\x1a.daml_lf_1.PackageMetadataR\x08metadata\x12\x36\n\x0einterned_types\x18\x05 \x03(\x0b\x32\x0f.daml_lf_1.TypeR\rinternedTypes*\xa5\x02\n\x08PrimType\x12\x08\n\x04UNIT\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\t\n\x05INT64\x10\x02\x12\x0b\n\x07\x44\x45\x43IMAL\x10\x03\x12\x08\n\x04TEXT\x10\x05\x12\r\n\tTIMESTAMP\x10\x06\x12\t\n\x05PARTY\x10\x08\x12\x08\n\x04LIST\x10\t\x12\n\n\x06UPDATE\x10\n\x12\x0c\n\x08SCENARIO\x10\x0b\x12\x08\n\x04\x44\x41TE\x10\x0c\x12\x0f\n\x0b\x43ONTRACT_ID\x10\r\x12\x0c\n\x08OPTIONAL\x10\x0e\x12\t\n\x05\x41RROW\x10\x0f\x12\x0b\n\x07TEXTMAP\x10\x10\x12\x0b\n\x07NUMERIC\x10\x11\x12\x07\n\x03\x41NY\x10\x12\x12\x0c\n\x08TYPE_REP\x10\x13\x12\n\n\x06GENMAP\x10\x14\x12\x0e\n\nBIGNUMERIC\x10\x15\x12\x11\n\rROUNDING_MODE\x10\x16\x12\x11\n\rANY_EXCEPTION\x10\x17*4\n\x07PrimCon\x12\x0c\n\x08\x43ON_UNIT\x10\x00\x12\r\n\tCON_FALSE\x10\x01\x12\x0c\n\x08\x43ON_TRUE\x10\x02*\xaa\x13\n\x0f\x42uiltinFunction\x12\x0f\n\x0b\x41\x44\x44_DECIMAL\x10\x00\x12\x0f\n\x0bSUB_DECIMAL\x10\x01\x12\x0f\n\x0bMUL_DECIMAL\x10\x02\x12\x0f\n\x0b\x44IV_DECIMAL\x10\x03\x12\x11\n\rROUND_DECIMAL\x10\x06\x12\x0f\n\x0b\x41\x44\x44_NUMERIC\x10k\x12\x0f\n\x0bSUB_NUMERIC\x10l\x12\x16\n\x12MUL_NUMERIC_LEGACY\x10m\x12\x10\n\x0bMUL_NUMERIC\x10\x95\x01\x12\x16\n\x12\x44IV_NUMERIC_LEGACY\x10n\x12\x10\n\x0b\x44IV_NUMERIC\x10\x96\x01\x12\x11\n\rROUND_NUMERIC\x10o\x12\x17\n\x13\x43\x41ST_NUMERIC_LEGACY\x10y\x12\x11\n\x0c\x43\x41ST_NUMERIC\x10\x97\x01\x12\x18\n\x14SHIFT_NUMERIC_LEGACY\x10z\x12\x12\n\rSHIFT_NUMERIC\x10\x98\x01\x12\r\n\tADD_INT64\x10\x07\x12\r\n\tSUB_INT64\x10\x08\x12\r\n\tMUL_INT64\x10\t\x12\r\n\tDIV_INT64\x10\n\x12\r\n\tMOD_INT64\x10\x0b\x12\r\n\tEXP_INT64\x10\x0c\x12\t\n\x05\x46OLDL\x10\x14\x12\t\n\x05\x46OLDR\x10\x15\x12\x11\n\rTEXTMAP_EMPTY\x10`\x12\x12\n\x0eTEXTMAP_INSERT\x10\x61\x12\x12\n\x0eTEXTMAP_LOOKUP\x10\x62\x12\x12\n\x0eTEXTMAP_DELETE\x10\x63\x12\x13\n\x0fTEXTMAP_TO_LIST\x10\x64\x12\x10\n\x0cTEXTMAP_SIZE\x10\x65\x12\x10\n\x0cGENMAP_EMPTY\x10|\x12\x11\n\rGENMAP_INSERT\x10}\x12\x11\n\rGENMAP_LOOKUP\x10~\x12\x11\n\rGENMAP_DELETE\x10\x7f\x12\x10\n\x0bGENMAP_KEYS\x10\x80\x01\x12\x12\n\rGENMAP_VALUES\x10\x81\x01\x12\x10\n\x0bGENMAP_SIZE\x10\x82\x01\x12\x10\n\x0c\x45XPLODE_TEXT\x10\x17\x12\x0f\n\x0b\x41PPEND_TEXT\x10\x18\x12\t\n\x05\x45RROR\x10\x19\x12\x1a\n\x15\x41NY_EXCEPTION_MESSAGE\x10\x93\x01\x12\r\n\tLEQ_INT64\x10!\x12\x0f\n\x0bLEQ_DECIMAL\x10\"\x12\x0f\n\x0bLEQ_NUMERIC\x10p\x12\x0c\n\x08LEQ_TEXT\x10$\x12\x11\n\rLEQ_TIMESTAMP\x10%\x12\x0c\n\x08LEQ_DATE\x10\x43\x12\r\n\tLEQ_PARTY\x10Y\x12\x0e\n\nLESS_INT64\x10\'\x12\x10\n\x0cLESS_DECIMAL\x10(\x12\x10\n\x0cLESS_NUMERIC\x10q\x12\r\n\tLESS_TEXT\x10*\x12\x12\n\x0eLESS_TIMESTAMP\x10+\x12\r\n\tLESS_DATE\x10\x44\x12\x0e\n\nLESS_PARTY\x10Z\x12\r\n\tGEQ_INT64\x10-\x12\x0f\n\x0bGEQ_DECIMAL\x10.\x12\x0f\n\x0bGEQ_NUMERIC\x10r\x12\x0c\n\x08GEQ_TEXT\x10\x30\x12\x11\n\rGEQ_TIMESTAMP\x10\x31\x12\x0c\n\x08GEQ_DATE\x10\x45\x12\r\n\tGEQ_PARTY\x10[\x12\x11\n\rGREATER_INT64\x10\x33\x12\x13\n\x0fGREATER_DECIMAL\x10\x34\x12\x13\n\x0fGREATER_NUMERIC\x10s\x12\x10\n\x0cGREATER_TEXT\x10\x36\x12\x15\n\x11GREATER_TIMESTAMP\x10\x37\x12\x10\n\x0cGREATER_DATE\x10\x46\x12\x11\n\rGREATER_PARTY\x10\\\x12\x11\n\rINT64_TO_TEXT\x10\x39\x12\x13\n\x0f\x44\x45\x43IMAL_TO_TEXT\x10:\x12\x13\n\x0fNUMERIC_TO_TEXT\x10t\x12\x10\n\x0cTEXT_TO_TEXT\x10<\x12\x15\n\x11TIMESTAMP_TO_TEXT\x10=\x12\x10\n\x0c\x44\x41TE_TO_TEXT\x10G\x12\x18\n\x14PARTY_TO_QUOTED_TEXT\x10?\x12\x11\n\rPARTY_TO_TEXT\x10^\x12\x11\n\rTEXT_TO_PARTY\x10_\x12\x11\n\rTEXT_TO_INT64\x10g\x12\x13\n\x0fTEXT_TO_DECIMAL\x10h\x12\x1a\n\x16TEXT_TO_NUMERIC_LEGACY\x10u\x12\x14\n\x0fTEXT_TO_NUMERIC\x10\x99\x01\x12\x18\n\x13\x43ONTRACT_ID_TO_TEXT\x10\x88\x01\x12\x0f\n\x0bSHA256_TEXT\x10]\x12\x15\n\x11\x44\x41TE_TO_UNIX_DAYS\x10H\x12\x15\n\x11UNIX_DAYS_TO_DATE\x10I\x12\"\n\x1eTIMESTAMP_TO_UNIX_MICROSECONDS\x10J\x12\"\n\x1eUNIX_MICROSECONDS_TO_TIMESTAMP\x10K\x12\x14\n\x10INT64_TO_DECIMAL\x10L\x12\x14\n\x10\x44\x45\x43IMAL_TO_INT64\x10M\x12\x1b\n\x17INT64_TO_NUMERIC_LEGACY\x10v\x12\x15\n\x10INT64_TO_NUMERIC\x10\x9a\x01\x12\x14\n\x10NUMERIC_TO_INT64\x10w\x12\x10\n\x0cIMPLODE_TEXT\x10N\x12\x0f\n\x0b\x45QUAL_INT64\x10O\x12\x11\n\rEQUAL_DECIMAL\x10P\x12\x11\n\rEQUAL_NUMERIC\x10x\x12\x0e\n\nEQUAL_TEXT\x10Q\x12\x13\n\x0f\x45QUAL_TIMESTAMP\x10R\x12\x0e\n\nEQUAL_DATE\x10S\x12\x0f\n\x0b\x45QUAL_PARTY\x10T\x12\x0e\n\nEQUAL_BOOL\x10U\x12\x15\n\x11\x45QUAL_CONTRACT_ID\x10V\x12\x0e\n\nEQUAL_LIST\x10W\x12\x12\n\x0e\x45QUAL_TYPE_REP\x10{\x12\n\n\x05\x45QUAL\x10\x83\x01\x12\x0c\n\x07LESS_EQ\x10\x84\x01\x12\t\n\x04LESS\x10\x85\x01\x12\x0f\n\nGREATER_EQ\x10\x86\x01\x12\x0c\n\x07GREATER\x10\x87\x01\x12\t\n\x05TRACE\x10X\x12\x16\n\x12\x43OERCE_CONTRACT_ID\x10\x66\x12\x17\n\x13\x43ODE_POINTS_TO_TEXT\x10i\x12\x17\n\x13TEXT_TO_CODE_POINTS\x10j\x12\x15\n\x10SCALE_BIGNUMERIC\x10\x89\x01\x12\x19\n\x14PRECISION_BIGNUMERIC\x10\x8a\x01\x12\x13\n\x0e\x41\x44\x44_BIGNUMERIC\x10\x8b\x01\x12\x13\n\x0eSUB_BIGNUMERIC\x10\x8c\x01\x12\x13\n\x0eMUL_BIGNUMERIC\x10\x8d\x01\x12\x13\n\x0e\x44IV_BIGNUMERIC\x10\x8e\x01\x12\x1b\n\x16SHIFT_RIGHT_BIGNUMERIC\x10\x8f\x01\x12!\n\x1c\x42IGNUMERIC_TO_NUMERIC_LEGACY\x10\x90\x01\x12\x1a\n\x15\x42IGNUMERIC_TO_NUMERIC\x10\x9b\x01\x12\x1a\n\x15NUMERIC_TO_BIGNUMERIC\x10\x91\x01\x12\x17\n\x12\x42IGNUMERIC_TO_TEXT\x10\x92\x01\x12\x18\n\x13TYPE_REP_TYCON_NAME\x10\x94\x01\x42m\n\x13\x63om.daml.daml_lf_16Z8github.com/digital-asset/dazl-client/v8/go/api/daml_lf_1\xaa\x02\x1b\x43om.Daml.Daml_Lf_16.DamlLf1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.daml_lf_1_16.daml_lf_1_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.daml.daml_lf_16Z8github.com/digital-asset/dazl-client/v8/go/api/daml_lf_1\252\002\033Com.Daml.Daml_Lf_16.DamlLf1'
  _globals['_PRIMTYPE']._serialized_start=22744
  _globals['_PRIMTYPE']._serialized_end=23037
  _globals['_PRIMCON']._serialized_start=23039
  _globals['_PRIMCON']._serialized_end=23091
  _globals['_BUILTINFUNCTION']._serialized_start=23094
  _globals['_BUILTINFUNCTION']._serialized_end=25568
  _globals['_UNIT']._serialized_start=52
  _globals['_UNIT']._serialized_end=58
  _globals['_PACKAGEREF']._serialized_start=61
  _globals['_PACKAGEREF']._serialized_end=216
  _globals['_DOTTEDNAME']._serialized_start=218
  _globals['_DOTTEDNAME']._serialized_end=258
  _globals['_MODULEREF']._serialized_start=261
  _globals['_MODULEREF']._serialized_end=475
  _globals['_TYPECONNAME']._serialized_start=478
  _globals['_TYPECONNAME']._serialized_end=651
  _globals['_TYPESYNNAME']._serialized_start=654
  _globals['_TYPESYNNAME']._serialized_end=827
  _globals['_VALNAME']._serialized_start=830
  _globals['_VALNAME']._serialized_end=964
  _globals['_FIELDWITHTYPE']._serialized_start=967
  _globals['_FIELDWITHTYPE']._serialized_end=1107
  _globals['_VARWITHTYPE']._serialized_start=1110
  _globals['_VARWITHTYPE']._serialized_end=1238
  _globals['_TYPEVARWITHKIND']._serialized_start=1241
  _globals['_TYPEVARWITHKIND']._serialized_end=1373
  _globals['_FIELDWITHEXPR']._serialized_start=1376
  _globals['_FIELDWITHEXPR']._serialized_end=1516
  _globals['_BINDING']._serialized_start=1518
  _globals['_BINDING']._serialized_end=1614
  _globals['_KIND']._serialized_start=1617
  _globals['_KIND']._serialized_end=1844
  _globals['_KIND_ARROW']._serialized_start=1748
  _globals['_KIND_ARROW']._serialized_end=1837
  _globals['_TYPE']._serialized_start=1847
  _globals['_TYPE']._serialized_end=2750
  _globals['_TYPE_VAR']._serialized_start=2172
  _globals['_TYPE_VAR']._serialized_end=2292
  _globals['_TYPE_CON']._serialized_start=2294
  _globals['_TYPE_CON']._serialized_end=2382
  _globals['_TYPE_SYN']._serialized_start=2384
  _globals['_TYPE_SYN']._serialized_end=2472
  _globals['_TYPE_PRIM']._serialized_start=2474
  _globals['_TYPE_PRIM']._serialized_end=2558
  _globals['_TYPE_FORALL']._serialized_start=2560
  _globals['_TYPE_FORALL']._serialized_end=2653
  _globals['_TYPE_STRUCT']._serialized_start=2655
  _globals['_TYPE_STRUCT']._serialized_end=2713
  _globals['_PRIMLIT']._serialized_start=2753
  _globals['_PRIMLIT']._serialized_end=3290
  _globals['_PRIMLIT_ROUNDINGMODE']._serialized_start=3155
  _globals['_PRIMLIT_ROUNDINGMODE']._serialized_end=3271
  _globals['_LOCATION']._serialized_start=3293
  _globals['_LOCATION']._serialized_end=3519
  _globals['_LOCATION_RANGE']._serialized_start=3400
  _globals['_LOCATION_RANGE']._serialized_end=3519
  _globals['_EXPR']._serialized_start=3522
  _globals['_EXPR']._serialized_end=11425
  _globals['_EXPR_RECCON']._serialized_start=6407
  _globals['_EXPR_RECCON']._serialized_end=6508
  _globals['_EXPR_RECPROJ']._serialized_start=6511
  _globals['_EXPR_RECPROJ']._serialized_end=6692
  _globals['_EXPR_RECUPD']._serialized_start=6695
  _globals['_EXPR_RECUPD']._serialized_end=6916
  _globals['_EXPR_VARIANTCON']._serialized_start=6919
  _globals['_EXPR_VARIANTCON']._serialized_end=7140
  _globals['_EXPR_ENUMCON']._serialized_start=7143
  _globals['_EXPR_ENUMCON']._serialized_end=7299
  _globals['_EXPR_STRUCTCON']._serialized_start=7301
  _globals['_EXPR_STRUCTCON']._serialized_end=7362
  _globals['_EXPR_STRUCTPROJ']._serialized_start=7365
  _globals['_EXPR_STRUCTPROJ']._serialized_end=7506
  _globals['_EXPR_STRUCTUPD']._serialized_start=7509
  _globals['_EXPR_STRUCTUPD']._serialized_end=7690
  _globals['_EXPR_APP']._serialized_start=7692
  _globals['_EXPR_APP']._serialized_end=7769
  _globals['_EXPR_TYAPP']._serialized_start=7771
  _globals['_EXPR_TYAPP']._serialized_end=7854
  _globals['_EXPR_ABS']._serialized_start=7856
  _globals['_EXPR_ABS']._serialized_end=7944
  _globals['_EXPR_TYABS']._serialized_start=7946
  _globals['_EXPR_TYABS']._serialized_end=8040
  _globals['_EXPR_NIL']._serialized_start=8042
  _globals['_EXPR_NIL']._serialized_end=8084
  _globals['_EXPR_CONS']._serialized_start=8086
  _globals['_EXPR_CONS']._serialized_end=8205
  _globals['_EXPR_OPTIONALNONE']._serialized_start=8207
  _globals['_EXPR_OPTIONALNONE']._serialized_end=8258
  _globals['_EXPR_OPTIONALSOME']._serialized_start=8260
  _globals['_EXPR_OPTIONALSOME']._serialized_end=8348
  _globals['_EXPR_TOANY']._serialized_start=8350
  _globals['_EXPR_TOANY']._serialized_end=8431
  _globals['_EXPR_FROMANY']._serialized_start=8433
  _globals['_EXPR_FROMANY']._serialized_end=8516
  _globals['_EXPR_TOANYEXCEPTION']._serialized_start=8518
  _globals['_EXPR_TOANYEXCEPTION']._serialized_end=8608
  _globals['_EXPR_FROMANYEXCEPTION']._serialized_start=8610
  _globals['_EXPR_FROMANYEXCEPTION']._serialized_end=8702
  _globals['_EXPR_THROW']._serialized_start=8705
  _globals['_EXPR_THROW']._serialized_end=8874
  _globals['_EXPR_TOINTERFACE']._serialized_start=8877
  _globals['_EXPR_TOINTERFACE']._serialized_end=9068
  _globals['_EXPR_FROMINTERFACE']._serialized_start=9071
  _globals['_EXPR_FROMINTERFACE']._serialized_end=9266
  _globals['_EXPR_CALLINTERFACE']._serialized_start=9269
  _globals['_EXPR_CALLINTERFACE']._serialized_end=9453
  _globals['_EXPR_VIEWINTERFACE']._serialized_start=9455
  _globals['_EXPR_VIEWINTERFACE']._serialized_end=9561
  _globals['_EXPR_SIGNATORYINTERFACE']._serialized_start=9563
  _globals['_EXPR_SIGNATORYINTERFACE']._serialized_end=9674
  _globals['_EXPR_OBSERVERINTERFACE']._serialized_start=9676
  _globals['_EXPR_OBSERVERINTERFACE']._serialized_end=9786
  _globals['_EXPR_UNSAFEFROMINTERFACE']._serialized_start=9789
  _globals['_EXPR_UNSAFEFROMINTERFACE']._serialized_end=10049
  _globals['_EXPR_TOREQUIREDINTERFACE']._serialized_start=10052
  _globals['_EXPR_TOREQUIREDINTERFACE']._serialized_end=10254
  _globals['_EXPR_FROMREQUIREDINTERFACE']._serialized_start=10257
  _globals['_EXPR_FROMREQUIREDINTERFACE']._serialized_end=10461
  _globals['_EXPR_UNSAFEFROMREQUIREDINTERFACE']._serialized_start=10464
  _globals['_EXPR_UNSAFEFROMREQUIREDINTERFACE']._serialized_end=10752
  _globals['_EXPR_INTERFACETEMPLATETYPEREP']._serialized_start=10754
  _globals['_EXPR_INTERFACETEMPLATETYPEREP']._serialized_end=10871
  _globals['_EXPR_CHOICECONTROLLER']._serialized_start=10874
  _globals['_EXPR_CHOICECONTROLLER']._serialized_end=11103
  _globals['_EXPR_CHOICEOBSERVER']._serialized_start=11106
  _globals['_EXPR_CHOICEOBSERVER']._serialized_end=11333
  _globals['_EXPR_EXPERIMENTAL']._serialized_start=11335
  _globals['_EXPR_EXPERIMENTAL']._serialized_end=11406
  _globals['_CASEALT']._serialized_start=11428
  _globals['_CASEALT']._serialized_end=12632
  _globals['_CASEALT_VARIANT']._serialized_start=11886
  _globals['_CASEALT_VARIANT']._serialized_end=12128
  _globals['_CASEALT_ENUM']._serialized_start=12131
  _globals['_CASEALT_ENUM']._serialized_end=12297
  _globals['_CASEALT_CONS']._serialized_start=12300
  _globals['_CASEALT_CONS']._serialized_end=12508
  _globals['_CASEALT_OPTIONALSOME']._serialized_start=12510
  _globals['_CASEALT_OPTIONALSOME']._serialized_end=12625
  _globals['_CASE']._serialized_start=12634
  _globals['_CASE']._serialized_end=12719
  _globals['_BLOCK']._serialized_start=12721
  _globals['_BLOCK']._serialized_end=12813
  _globals['_PURE']._serialized_start=12815
  _globals['_PURE']._serialized_end=12895
  _globals['_UPDATE']._serialized_start=12898
  _globals['_UPDATE']._serialized_end=15974
  _globals['_UPDATE_CREATE']._serialized_start=13986
  _globals['_UPDATE_CREATE']._serialized_end=14083
  _globals['_UPDATE_CREATEINTERFACE']._serialized_start=14085
  _globals['_UPDATE_CREATEINTERFACE']._serialized_end=14193
  _globals['_UPDATE_EXERCISE']._serialized_start=14196
  _globals['_UPDATE_EXERCISE']._serialized_end=14427
  _globals['_UPDATE_SOFTEXERCISE']._serialized_start=14430
  _globals['_UPDATE_SOFTEXERCISE']._serialized_end=14659
  _globals['_UPDATE_DYNAMICEXERCISE']._serialized_start=14662
  _globals['_UPDATE_DYNAMICEXERCISE']._serialized_end=14849
  _globals['_UPDATE_EXERCISEINTERFACE']._serialized_start=14852
  _globals['_UPDATE_EXERCISEINTERFACE']._serialized_end=15082
  _globals['_UPDATE_EXERCISEBYKEY']._serialized_start=15085
  _globals['_UPDATE_EXERCISEBYKEY']._serialized_end=15270
  _globals['_UPDATE_FETCH']._serialized_start=15272
  _globals['_UPDATE_FETCH']._serialized_end=15372
  _globals['_UPDATE_SOFTFETCH']._serialized_start=15374
  _globals['_UPDATE_SOFTFETCH']._serialized_end=15472
  _globals['_UPDATE_FETCHINTERFACE']._serialized_start=15474
  _globals['_UPDATE_FETCHINTERFACE']._serialized_end=15579
  _globals['_UPDATE_EMBEDEXPR']._serialized_start=15581
  _globals['_UPDATE_EMBEDEXPR']._serialized_end=15666
  _globals['_UPDATE_RETRIEVEBYKEY']._serialized_start=15668
  _globals['_UPDATE_RETRIEVEBYKEY']._serialized_end=15770
  _globals['_UPDATE_TRYCATCH']._serialized_start=15773
  _globals['_UPDATE_TRYCATCH']._serialized_end=15967
  _globals['_SCENARIO']._serialized_start=15977
  _globals['_SCENARIO']._serialized_end=16606
  _globals['_SCENARIO_COMMIT']._serialized_start=16384
  _globals['_SCENARIO_COMMIT']._serialized_end=16512
  _globals['_SCENARIO_EMBEDEXPR']._serialized_start=15581
  _globals['_SCENARIO_EMBEDEXPR']._serialized_end=15666
  _globals['_TEMPLATECHOICE']._serialized_start=16609
  _globals['_TEMPLATECHOICE']._serialized_end=17192
  _globals['_KEYEXPR']._serialized_start=17195
  _globals['_KEYEXPR']._serialized_end=17811
  _globals['_KEYEXPR_PROJECTION']._serialized_start=17328
  _globals['_KEYEXPR_PROJECTION']._serialized_end=17471
  _globals['_KEYEXPR_PROJECTIONS']._serialized_start=17473
  _globals['_KEYEXPR_PROJECTIONS']._serialized_end=17551
  _globals['_KEYEXPR_RECORDFIELD']._serialized_start=17554
  _globals['_KEYEXPR_RECORDFIELD']._serialized_end=17695
  _globals['_KEYEXPR_RECORD']._serialized_start=17697
  _globals['_KEYEXPR_RECORD']._serialized_end=17804
  _globals['_INTERFACEINSTANCEBODY']._serialized_start=17814
  _globals['_INTERFACEINSTANCEBODY']._serialized_end=18074
  _globals['_INTERFACEINSTANCEBODY_INTERFACEINSTANCEMETHOD']._serialized_start=17960
  _globals['_INTERFACEINSTANCEBODY_INTERFACEINSTANCEMETHOD']._serialized_end=18074
  _globals['_DEFTEMPLATE']._serialized_start=18077
  _globals['_DEFTEMPLATE']._serialized_end=19084
  _globals['_DEFTEMPLATE_DEFKEY']._serialized_start=18688
  _globals['_DEFTEMPLATE_DEFKEY']._serialized_end=18888
  _globals['_DEFTEMPLATE_IMPLEMENTS']._serialized_start=18891
  _globals['_DEFTEMPLATE_IMPLEMENTS']._serialized_end=19060
  _globals['_INTERFACEMETHOD']._serialized_start=19087
  _globals['_INTERFACEMETHOD']._serialized_end=19240
  _globals['_DEFINTERFACE']._serialized_start=19243
  _globals['_DEFINTERFACE']._serialized_end=19844
  _globals['_DEFINTERFACE_COIMPLEMENTS']._serialized_start=19675
  _globals['_DEFINTERFACE_COIMPLEMENTS']._serialized_end=19844
  _globals['_DEFEXCEPTION']._serialized_start=19847
  _globals['_DEFEXCEPTION']._serialized_end=20001
  _globals['_DEFDATATYPE']._serialized_start=20004
  _globals['_DEFDATATYPE']._serialized_end=20691
  _globals['_DEFDATATYPE_FIELDS']._serialized_start=20490
  _globals['_DEFDATATYPE_FIELDS']._serialized_end=20548
  _globals['_DEFDATATYPE_ENUMCONSTRUCTORS']._serialized_start=20550
  _globals['_DEFDATATYPE_ENUMCONSTRUCTORS']._serialized_end=20671
  _globals['_DEFTYPESYN']._serialized_start=20694
  _globals['_DEFTYPESYN']._serialized_end=20958
  _globals['_DEFVALUE']._serialized_start=20961
  _globals['_DEFVALUE']._serialized_end=21331
  _globals['_DEFVALUE_NAMEWITHTYPE']._serialized_start=21201
  _globals['_DEFVALUE_NAMEWITHTYPE']._serialized_end=21331
  _globals['_FEATUREFLAGS']._serialized_start=21334
  _globals['_FEATUREFLAGS']._serialized_end=21584
  _globals['_MODULE']._serialized_start=21587
  _globals['_MODULE']._serialized_end=22087
  _globals['_INTERNEDDOTTEDNAME']._serialized_start=22089
  _globals['_INTERNEDDOTTEDNAME']._serialized_end=22161
  _globals['_UPGRADEDPACKAGEID']._serialized_start=22163
  _globals['_UPGRADEDPACKAGEID']._serialized_end=22254
  _globals['_PACKAGEMETADATA']._serialized_start=22257
  _globals['_PACKAGEMETADATA']._serialized_end=22446
  _globals['_PACKAGE']._serialized_start=22449
  _globals['_PACKAGE']._serialized_end=22741
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v3/participant_transaction.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v3/participant_transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from ..v0 import participant_transaction_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_participant__transaction__pb2
from ..v1 import participant_transaction_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_participant__transaction__pb2
from ..v2 import participant_transaction_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v2_dot_participant__transaction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAcom/digitalasset/canton/protocol/v3/participant_transaction.proto\x12#com.digitalasset.canton.protocol.v3\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a\x41\x63om/digitalasset/canton/protocol/v0/participant_transaction.proto\x1a\x41\x63om/digitalasset/canton/protocol/v1/participant_transaction.proto\x1a\x41\x63om/digitalasset/canton/protocol/v2/participant_transaction.proto\"\x94\x05\n\x13ViewParticipantData\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12S\n\x0b\x63ore_inputs\x18\x02 \x03(\x0b\x32\x32.com.digitalasset.canton.protocol.v1.InputContractR\ncoreInputs\x12W\n\x0c\x63reated_core\x18\x03 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v1.CreatedContractR\x0b\x63reatedCore\x12K\n#created_in_subview_archived_in_core\x18\x04 \x03(\tR\x1e\x63reatedInSubviewArchivedInCore\x12i\n\rresolved_keys\x18\x05 \x03(\x0b\x32\x44.com.digitalasset.canton.protocol.v0.ViewParticipantData.ResolvedKeyR\x0cresolvedKeys\x12\x65\n\x12\x61\x63tion_description\x18\x06 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v2.ActionDescriptionR\x11\x61\x63tionDescription\x12s\n\x10rollback_context\x18\x07 \x01(\x0b\x32H.com.digitalasset.canton.protocol.v0.ViewParticipantData.RollbackContextR\x0frollbackContext\"\xff\x06\n\x11\x41\x63tionDescription\x12h\n\x06\x63reate\x18\x01 \x01(\x0b\x32N.com.digitalasset.canton.protocol.v0.ActionDescription.CreateActionDescriptionH\x00R\x06\x63reate\x12n\n\x08\x65xercise\x18\x02 \x01(\x0b\x32P.com.digitalasset.canton.protocol.v3.ActionDescription.ExerciseActionDescriptionH\x00R\x08\x65xercise\x12\x65\n\x05\x66\x65tch\x18\x03 \x01(\x0b\x32M.com.digitalasset.canton.protocol.v1.ActionDescription.FetchActionDescriptionH\x00R\x05\x66\x65tch\x12y\n\rlookup_by_key\x18\x04 \x01(\x0b\x32S.com.digitalasset.canton.protocol.v1.ActionDescription.LookupByKeyActionDescriptionH\x00R\x0blookupByKey\x1a\x9e\x03\n\x19\x45xerciseActionDescription\x12*\n\x11input_contract_id\x18\x01 \x01(\tR\x0finputContractId\x12\x16\n\x06\x63hoice\x18\x02 \x01(\tR\x06\x63hoice\x12!\n\x0c\x63hosen_value\x18\x03 \x01(\x0cR\x0b\x63hosenValue\x12\x16\n\x06\x61\x63tors\x18\x04 \x03(\tR\x06\x61\x63tors\x12\x15\n\x06\x62y_key\x18\x05 \x01(\x08R\x05\x62yKey\x12\x1b\n\tnode_seed\x18\x06 \x01(\x0cR\x08nodeSeed\x12\x18\n\x07version\x18\x07 \x01(\tR\x07version\x12\x16\n\x06\x66\x61iled\x18\x08 \x01(\x08R\x06\x66\x61iled\x12&\n\x0cinterface_id\x18\t \x01(\tH\x00R\x0binterfaceId\x88\x01\x01\x12$\n\x0btemplate_id\x18\n \x01(\tH\x01R\ntemplateId\x88\x01\x01\x12-\n\x12package_preference\x18\x0b \x03(\tR\x11packagePreferenceB\x0f\n\r_interface_idB\x0e\n\x0c_template_idB\r\n\x0b\x64\x65scriptionBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v3.participant_transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v3'
  _globals['_VIEWPARTICIPANTDATA']._serialized_start=356
  _globals['_VIEWPARTICIPANTDATA']._serialized_end=1016
  _globals['_ACTIONDESCRIPTION']._serialized_start=1019
  _globals['_ACTIONDESCRIPTION']._serialized_end=1914
  _globals['_ACTIONDESCRIPTION_EXERCISEACTIONDESCRIPTION']._serialized_start=1485
  _globals['_ACTIONDESCRIPTION_EXERCISEACTIONDESCRIPTION']._serialized_end=1899
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MemberTrafficStatus(_message.Message):
    __slots__ = ("member", "total_extra_traffic_limit", "total_extra_traffic_consumed", "top_up_events", "ts")
    class TopUpEvent(_message.Message):
        __slots__ = ("effective_at", "serial", "extra_traffic_limit")
        EFFECTIVE_AT_FIELD_NUMBER: _ClassVar[int]
        SERIAL_FIELD_NUMBER: _ClassVar[int]
        EXTRA_TRAFFIC_LIMIT_FIELD_NUMBER: _ClassVar[int]
        effective_at: _timestamp_pb2.Timestamp
        serial: int
        extra_traffic_limit: int
        def __init__(self, effective_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., serial: _Optional[int] = ..., extra_traffic_limit: _Optional[int] = ...) -> None: ...
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    TOTAL_EXTRA_TRAFFIC_LIMIT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_EXTRA_TRAFFIC_CONSUMED_FIELD_NUMBER: _ClassVar[int]
    TOP_UP_EVENTS_FIELD_NUMBER: _ClassVar[int]
    TS_FIELD_NUMBER: _ClassVar[int]
    member: str
    total_extra_traffic_limit: _wrappers_pb2.UInt64Value
    total_extra_traffic_consumed: int
    top_up_events: _containers.RepeatedCompositeFieldContainer[MemberTrafficStatus.TopUpEvent]
    ts: _timestamp_pb2.Timestamp
    def __init__(self, member: _Optional[str] = ..., total_extra_traffic_limit: _Optional[_Union[_wrappers_pb2.UInt64Value, _Mapping]] = ..., total_extra_traffic_consumed: _Optional[int] = ..., top_up_events: _Optional[_Iterable[_Union[MemberTrafficStatus.TopUpEvent, _Mapping]]] = ..., ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/admin/v30/sequencer_version_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/sequencer/admin/v30/sequencer_version_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_sequencing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKcom/digitalasset/canton/sequencer/admin/v30/sequencer_version_service.proto\x12+com.digitalasset.canton.sequencer.admin.v30\x1a\x35\x63om/digitalasset/canton/protocol/v30/sequencing.proto\"\x8a\x02\n\x10SequencerVersion\x1ax\n\x10HandshakeRequest\x12\x64\n\x11handshake_request\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.Handshake.RequestR\x10handshakeRequest\x1a|\n\x11HandshakeResponse\x12g\n\x12handshake_response\x18\x01 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.Handshake.ResponseR\x11handshakeResponse2\xc8\x01\n\x17SequencerVersionService\x12\xac\x01\n\tHandshake\x12N.com.digitalasset.canton.sequencer.admin.v30.SequencerVersion.HandshakeRequest\x1aO.com.digitalasset.canton.sequencer.admin.v30.SequencerVersion.HandshakeResponseB\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.admin.v30.sequencer_version_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30'
  _globals['_SEQUENCERVERSION']._serialized_start=180
  _globals['_SEQUENCERVERSION']._serialized_end=446
  _globals['_SEQUENCERVERSION_HANDSHAKEREQUEST']._serialized_start=200
  _globals['_SEQUENCERVERSION_HANDSHAKEREQUEST']._serialized_end=320
  _globals['_SEQUENCERVERSION_HANDSHAKERESPONSE']._serialized_start=322
  _globals['_SEQUENCERVERSION_HANDSHAKERESPONSE']._serialized_end=446
  _globals['_SEQUENCERVERSIONSERVICE']._serialized_start=449
  _globals['_SEQUENCERVERSIONSERVICE']._serialized_end=649
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetLedgerConfigurationRequest(_message.Message):
    __slots__ = ("ledger_id",)
    LEDGER_ID_FIELD_NUMBER: _ClassVar[int]
    ledger_id: str
    def __init__(self, ledger_id: _Optional[str] = ...) -> None: ...

class GetLedgerConfigurationResponse(_message.Message):
    __slots__ = ("ledger_configuration",)
    LEDGER_CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    ledger_configuration: LedgerConfiguration
    def __init__(self, ledger_configuration: _Optional[_Union[LedgerConfiguration, _Mapping]] = ...) -> None: ...

class LedgerConfiguration(_message.Message):
    __slots__ = ("max_deduplication_duration",)
    MAX_DEDUPLICATION_DURATION_FIELD_NUMBER: _ClassVar[int]
    max_deduplication_duration: _duration_pb2.Duration
    def __init__(self, max_deduplication_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....crypto.v0 import crypto_pb2 as _crypto_pb2
from ....protocol.v0 import sequencing_pb2 as _sequencing_pb2
from ....protocol.v1 import sequencing_pb2 as _sequencing_pb2_1
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetDomainParameters(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Response(_message.Message):
        __slots__ = ("parameters_v0", "parameters_v1")
        PARAMETERS_V0_FIELD_NUMBER: _ClassVar[int]
        PARAMETERS_V1_FIELD_NUMBER: _ClassVar[int]
        parameters_v0: _sequencing_pb2.StaticDomainParameters
        parameters_v1: _sequencing_pb2_1.StaticDomainParameters
        def __init__(self, parameters_v0: _Optional[_Union[_sequencing_pb2.StaticDomainParameters, _Mapping]] = ..., parameters_v1: _Optional[_Union[_sequencing_pb2_1.StaticDomainParameters, _Mapping]] = ...) -> None: ...
    def __init__(self) -> None: ...

class ServiceAgreementAcceptances(_message.Message):
    __slots__ = ("acceptances",)
    ACCEPTANCES_FIELD_NUMBER: _ClassVar[int]
    acceptances: _containers.RepeatedCompositeFieldContainer[ServiceAgreementAcceptance]
    def __init__(self, acceptances: _Optional[_Iterable[_Union[ServiceAgreementAcceptance, _Mapping]]] = ...) -> None: ...

class ServiceAgreementAcceptance(_message.Message):
    __slots__ = ("agreement_id", "participant_id", "signature", "timestamp")
    AGREEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    agreement_id: str
    participant_id: str
    signature: _crypto_pb2.Signature
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, agreement_id: _Optional[str] = ..., participant_id: _Optional[str] = ..., signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .sequencer_administration_service_pb2 import DisableMemberRequest, DisableMemberResponse, OnboardingStateRequest, OnboardingStateResponse, PruningStatusRequest, PruningStatusResponse, SetTrafficPurchasedRequest, SetTrafficPurchasedResponse, SnapshotRequest, SnapshotResponse, TrafficControlStateRequest, TrafficControlStateResponse

__all__ = [
    "SequencerAdministrationServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class SequencerAdministrationServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _SequencerAdministrationServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _SequencerAdministrationServiceAsyncStub: ...  # type: ignore
    def PruningStatus(self, __1: PruningStatusRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[PruningStatusResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, PruningStatusResponse]]: ...
    def TrafficControlState(self, __1: TrafficControlStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[TrafficControlStateResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, TrafficControlStateResponse]]: ...
    def SetTrafficPurchased(self, __1: SetTrafficPurchasedRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetTrafficPurchasedResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SetTrafficPurchasedResponse]]: ...
    def Snapshot(self, __1: SnapshotRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SnapshotResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SnapshotResponse]]: ...
    def OnboardingState(self, __1: OnboardingStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[OnboardingStateResponse], _grpc_aio.UnaryStreamCall[_typing.Any, OnboardingStateResponse]]: ...
    def DisableMember(self, __1: DisableMemberRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[DisableMemberResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, DisableMemberResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerAdministrationServiceBlockingStub(SequencerAdministrationServiceStub):
    def PruningStatus(self, __1: PruningStatusRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> PruningStatusResponse: ...
    def TrafficControlState(self, __1: TrafficControlStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> TrafficControlStateResponse: ...
    def SetTrafficPurchased(self, __1: SetTrafficPurchasedRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetTrafficPurchasedResponse: ...
    def Snapshot(self, __1: SnapshotRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SnapshotResponse: ...
    def OnboardingState(self, __1: OnboardingStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[OnboardingStateResponse]: ...
    def DisableMember(self, __1: DisableMemberRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> DisableMemberResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerAdministrationServiceAsyncStub(SequencerAdministrationServiceStub):
    def PruningStatus(self, __1: PruningStatusRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, PruningStatusResponse]: ...  # type: ignore
    def TrafficControlState(self, __1: TrafficControlStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, TrafficControlStateResponse]: ...  # type: ignore
    def SetTrafficPurchased(self, __1: SetTrafficPurchasedRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetTrafficPurchasedResponse]: ...  # type: ignore
    def Snapshot(self, __1: SnapshotRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SnapshotResponse]: ...  # type: ignore
    def OnboardingState(self, __1: OnboardingStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, OnboardingStateResponse]: ...  # type: ignore
    def DisableMember(self, __1: DisableMemberRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, DisableMemberResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from os import PathLike
from typing import Optional

from ...damlast.lookup import MultiPackageLookup
from ...prim import Parties, TimeDeltaLike
from .conn_aio import Connection

__all__ = ["connect", "Connection"]

# TODO: Figure out clever ways to make this function's type signature easier to maintain while
#  preserving its ease of use to callers.
def connect(
    url: str,
    *,
    read_as: Optional[Parties] = None,
    act_as: Optional[Parties] = None,
    admin: Optional[bool] = False,
    ledger_id: Optional[str] = None,
    application_name: Optional[str] = None,
    oauth_token: Optional[str] = None,
    ca: Optional[bytes] = None,
    ca_file: Optional[PathLike] = None,
    cert: Optional[bytes] = None,
    cert_file: Optional[PathLike] = None,
    cert_key: Optional[bytes] = None,
    cert_key_file: Optional[PathLike] = None,
    connect_timeout: Optional[TimeDeltaLike] = None,
    enable_http_proxy: bool = True,
    lookup: Optional[MultiPackageLookup] = None,
) -> Connection: ...
